# Dorado data files

orbits.txt
: selected two-line elements retrieved from
  https://www.celestrak.com/
  on Fri Oct 30 22:20:28 EDT 2020.

L_SAA_2008198.03
: SAA bounding polygon used by Fermi tools, retrieved from
  https://fermi.gsfc.nasa.gov/ssc/data/analysis/scitools/data/OrbSim/L_SAA_2008198.03
